#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# 2023, marcus.klein@iteratio.com

from .agent_based_api.v1 import (
    register,
    Result,
    Service,
    State,
    check_levels,
    Metric,
)

def parse_mshpc_jobtemplate(string_table):
    try:
        data = eval("".join([i[0] for i in string_table]))
    except:
        data = {}
    return data


register.agent_section(
    name="mshpc_jobtemplate",
    parse_function=parse_mshpc_jobtemplate,
)


def discover_mshpc_jobtemplate(section):
    for item in section:
        yield Service(item=item)


def check_mshpc_jobtemplate(item, params, section):
    if not (data := section.get(item)):
        yield Result(state=State.UNKNOWN, summary="No data from host")
        return

    jobs_total = 0

    for key, value in data.items():
        levels = params.get(f"jobs_{key.lower()}", {})
        jobs_total += value
        yield from check_levels(
            value,
            levels_upper=levels.get("upper"),
            levels_lower=levels.get("lower"),
            metric_name=f"mshpc_jobs_state_{key.lower()}",
            render_func=int,
            label=key,
        )

    yield Metric("MSHPC_jobs_Total", jobs_total)
    yield Result(state=State.OK, summary=f"Jobs total: {jobs_total}")


register.check_plugin(
    name="mshpc_jobtemplate",
    service_name="MSHPC JobTemplate %s",
    discovery_function=discover_mshpc_jobtemplate,
    check_function=check_mshpc_jobtemplate,
    check_default_parameters={},
    check_ruleset_name="mshpc_jobtemplate",
)
